#' Eye color of couples
#'
#' Colors of the eye colors of male and female partners.
#'
#'
#' @name assortive_mating
#' @aliases assortive.mating assortive_mating
#' @docType data
#' @format A data frame with 204 observations on the following 2 variables.
#' \describe{
#'   \item{self_male}{a factor with levels `blue`, `brown`, and `green`}
#'   \item{partner_female}{a factor with `blue`, `brown`, and `green`}
#' }
#' @source B. Laeng et al. Why do blue-eyed men prefer women with the same eye
#' color? In: Behavioral Ecology and Sociobiology 61.3 (2007), pp. 371-384.
#' @keywords datasets
#' @examples
#'
#' data(assortive_mating)
#' table(assortive_mating)
"assortative_mating"
